# py4hw

[![PyPI version](https://badge.fury.io/py/py4hw.svg)](https://badge.fury.io/py/py4hw)
[![Join the chat at https://gitter.im/davidcastells/py4hw](https://badges.gitter.im/davidcastells/py4hw.svg)](https://gitter.im/davidcastells/py4hw?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

py4hw is an HDL library based on python to create digital circuits (mainly) following a structural design methodology. 
It is highly influenced by the JHDL principles but using the power of Python.

[Follow the jump start tutorial !](tutorial/README.md)
